Lazy Load Images After 5 Second Timeout

# Lazy Load Plugin for jQuery

Blog Projects

## Load images after five second delay

Here Lazy Load plugin is enabled. Images are not loaded. Timeout will trigger five seconds after all other elements of page have been loaded.

    $(function() {
        $("img.lazy").lazyload({
            event : "sporty"
        });
    });

    $(window).bind("load", function() {
        var timeout = setTimeout(function() { $("img.lazy").trigger("sporty") }, 5000);
    });

    <img class="lazy" src="img/grey.gif" data-original="img/example.jpg" width="765" height="574">